#!/usr/bin/env python3
#
# Copyright 2021 Graviti. Licensed under MIT License.
#
# pylint: disable=invalid-name

"""Dataloader of the CADC dataset."""

from tensorbay.opendataset.CADC.loader import CADC

__all__ = ["CADC"]
